@@ -52,23 +52,22 @@ sub build_self {
 
 # METHODS
 
-sub assertion {
-  my ($self) = @_;
+sub arguments {
+  my ($self, $index) = @_;
 
-  my $assert = $self->SUPER::assertion;
+  my $captured = $self->captured;
 
-  $assert->clear->expression('string');
+  return undef if !$captured;
 
-  return $assert;
+  my $arguments = $captured->{arguments};
+
+  return $arguments if !defined $index;
+
+  return undef if !$arguments;
+
+  return $arguments->[$index];
 }
 
-sub id {
-  my ($self, $name) = @_;
-
-  $name = lc $name =~ s/\W+/_/gr if $name;
-
-  return $name;
-}
 
 sub as {
   my ($self, $name) = @_;
@@ -86,6 +85,46 @@ sub as {
   return $self->$method;
 }
 
+sub assertion {
+  my ($self) = @_;
+
+  my $assert = $self->SUPER::assertion;
+
+  $assert->clear->expression('string');
+
+  return $assert;
+}
+
+sub callframe {
+  my ($self, $index) = @_;
+
+  my $captured = $self->captured;
+
+  return undef if !$captured;
+
+  my $callframe = $captured->{callframe};
+
+  return $callframe if !defined $index;
+
+  return undef if !$callframe;
+
+  return $callframe->[$index];
+}
+
+sub captured {
+  my ($self) = @_;
+
+  return $self->stash('captured');
+}
+
+sub id {
+  my ($self, $name) = @_;
+
+  $name = lc $name =~ s/\W+/_/gr if $name;
+
+  return $name;
+}
+
 sub explain {
   my ($self) = @_;
 
@@ -337,6 +376,61 @@ This package provides the following methods:
 
 =cut
 
+=head2 arguments
+
+  arguments(Int $index) (Any)
+
+The arguments method returns the stashed arguments under L</captured>, or a
+specific argument if an index is provided.
+
+I<Since C<2.55>>
+
+=over 4
+
+=item arguments example 1
+
+  # given: synopsis
+
+  my $arguments = $error->arguments;
+
+  # undef
+
+=back
+
+=over 4
+
+=item arguments example 2
+
+  package main;
+
+  use Venus::Throw;
+
+  my $error = Venus::Throw->new->capture(1..4)->catch('error');
+
+  my $arguments = $error->arguments;
+
+  # [1..4]
+
+=back
+
+=over 4
+
+=item arguments example 3
+
+  package main;
+
+  use Venus::Throw;
+
+  my $error = Venus::Throw->new->capture(1..4)->catch('error');
+
+  my $arguments = $error->arguments(0);
+
+  # 1
+
+=back
+
+=cut
+
 =head2 as
 
   as(Str $name) (Error)
@@ -482,6 +576,83 @@ I<Since C<1.02>>
 
 =cut
 
+=head2 callframe
+
+  callframe(Int $index) (Any)
+
+The callframe method returns the stashed callframe under L</captured>, or a
+specific argument if an index is provided.
+
+I<Since C<2.55>>
+
+=over 4
+
+=item callframe example 1
+
+  # given: synopsis
+
+  my $callframe = $error->callframe;
+
+  # undef
+
+=back
+
+=over 4
+
+=item callframe example 2
+
+  package main;
+
+  use Venus::Throw;
+
+  my $error = Venus::Throw->new->do('frame', 0)->capture->catch('error');
+
+  my $callframe = $error->callframe;
+
+  # [...]
+
+=back
+
+=over 4
+
+=item callframe example 3
+
+  package main;
+
+  use Venus::Throw;
+
+  my $error = Venus::Throw->new->do('frame', 0)->capture->catch('error');
+
+  my $package = $error->callframe(0);
+
+  # 'main'
+
+=back
+
+=cut
+
+=head2 captured
+
+  captured() (HashRef)
+
+The captured method returns the value stashed as C<"captured">.
+
+I<Since C<2.55>>
+
+=over 4
+
+=item captured example 1
+
+  # given: synopsis
+
+  my $captured = $error->captured;
+
+  # undef
+
+=back
+
+=cut
+
 =head2 explain
 
   explain() (Str)
