@@ -2055,4 +2055,19 @@ B<example 1>
 
   # 1
 
-=back
\ No newline at end of file
+=back
+
+=head1 AUTHORS
+
+Awncorp, C<awncorp@cpan.org>
+
+=cut
+
+=head1 LICENSE
+
+Copyright (C) 2000, Al Newkirk.
+
+This program is free software, you can redistribute it and/or modify it under
+the terms of the Apache license version 2.0.
+
+=cut
\ No newline at end of file
